@@ -32,16 +32,8 @@
 #include <string.h>
 #include <glib/gi18n-lib.h>
 
-#include <libekolabutil/kolab-util-camel.h>
 #include <libekolabutil/camel-system-headers.h>
-
-/* IMAPX specifics
- *
- *      The following header files are not installed,
- *      their API is not public to Camel users, so we
- *      need to keep our own local IMAPX around.
- */
-#include <camel/providers/imapx/camel-imapx-utils.h>
+#include <libekolabutil/kolab-util-camel.h>
 
 #include "camel-kolab-imapx-provider.h"
 #include "camel-kolab-imapx-store.h"
