@@ -46,8 +46,6 @@
 #include <libedataserver/e-account.h>
 #include <libedataserverui/e-passwords.h>
 
-#include <libekolabutil/camel-system-headers.h>
-
 /* Kolab error reporting */
 #include <libekolabutil/kolab-util-error.h>
 
@@ -168,7 +166,7 @@ kolab_session_get_password (CamelSession *self,
 	return g_strdup (priv->passwd);
 }
 
-static void
+static gboolean
 kolab_session_forget_password (CamelSession *self,
                                CamelService *service,
                                const gchar *item,
@@ -181,7 +179,7 @@ kolab_session_forget_password (CamelSession *self,
 
 	g_assert (CAMEL_IS_KOLAB_SESSION (self));
 	g_assert (CAMEL_IS_KOLAB_IMAPX_STORE (service));
-	g_return_if_fail (err == NULL || *err == NULL);
+	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
 	(void)item;
 
@@ -192,6 +190,8 @@ kolab_session_forget_password (CamelSession *self,
 		g_free (priv->passwd);
 		priv->passwd = NULL;
 	}
+
+	return TRUE;
 }
 
 static gboolean
@@ -345,13 +345,6 @@ camel_kolab_session_class_init (CamelKolabSessionClass *klass)
 	session_class->add_service = parent_class->add_service;
 	session_class->get_password = kolab_session_get_password;
 	session_class->forget_password = kolab_session_forget_password;
-#if 0
-	session_class->alert_user = kolab_session_alert_user;
-	session_class->get_filter_driver = kolab_session_get_filter_driver;
-	session_class->lookup_addressbook = kolab_session_lookup_addressbook;
-	session_class->forward_to = kolab_session_forward_to;
-	session_class->get_socks_proxy = kolab_session_get_socks_proxy;
-#endif
 	session_class->authenticate_sync = kolab_session_authenticate_sync;
 }
 
