@@ -390,7 +390,7 @@ e_kolab_account_setup_backend_create (EPlugin *epl,
 
 	/* Server section */
 	section = gtk_label_new (NULL);
-	tmp_str = g_strconcat ("<b>", _("Kolab Server Settings"), "</b>", NULL);
+	tmp_str = g_strconcat ("<b>", C_("Account Setup", "Kolab Server Settings"), "</b>", NULL);
 	gtk_label_set_markup (GTK_LABEL (section), tmp_str);
 	g_free (tmp_str);
 	gtk_misc_set_alignment (GTK_MISC (section), 0.0, 0.0);
@@ -401,9 +401,7 @@ e_kolab_account_setup_backend_create (EPlugin *epl,
 	gtk_box_pack_start (GTK_BOX (kolab_vbox), GTK_WIDGET (hbox), TRUE, TRUE, 0);
 	spacer = gtk_label_new("   ");
 	gtk_box_pack_start (GTK_BOX (hbox), spacer, FALSE, FALSE, 0);
-	tmp_str = g_strconcat (_("Kolab Account"), ":", NULL);
-	label = gtk_label_new_with_mnemonic (tmp_str);
-	g_free (tmp_str);
+	label = gtk_label_new (C_("Account Setup", "Kolab Account:"));
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	uidata->kolab_accounts_avail = GTK_COMBO_BOX_TEXT (gtk_combo_box_text_new ());
 	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (uidata->kolab_accounts_avail), TRUE, TRUE, 0);
@@ -416,11 +414,9 @@ e_kolab_account_setup_backend_create (EPlugin *epl,
 	gtk_box_pack_start (GTK_BOX (kolab_vbox), GTK_WIDGET (hbox), TRUE, TRUE, 0);
 	spacer = gtk_label_new("   ");
 	gtk_box_pack_start (GTK_BOX (hbox), spacer, FALSE, FALSE, 0);
-	tmp_str = g_strconcat (_("Kolab Server"), ":", NULL);
-	label = gtk_label_new(tmp_str);
-	g_free (tmp_str);
+	label = gtk_label_new(C_("Account Setup", "Kolab Server:"));
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-	uidata->kolab_servername = GTK_ENTRY(gtk_entry_new());
+	uidata->kolab_servername = GTK_ENTRY (gtk_entry_new());
 	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (uidata->kolab_servername), TRUE, TRUE, 0);
 
 	/* Kolab user name option */
@@ -428,11 +424,9 @@ e_kolab_account_setup_backend_create (EPlugin *epl,
 	gtk_box_pack_start (GTK_BOX (kolab_vbox), GTK_WIDGET (hbox), TRUE, TRUE, 0);
 	spacer = gtk_label_new("   ");
 	gtk_box_pack_start (GTK_BOX (hbox), spacer, FALSE, FALSE, 0);
-	tmp_str = g_strconcat (_("User ID"), ":", NULL);
-	label = gtk_label_new_with_mnemonic (tmp_str);
-	g_free (tmp_str);
+	label = gtk_label_new (C_("Account Setup", "User ID:"));
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-	uidata->kolab_username = GTK_ENTRY(gtk_entry_new());
+	uidata->kolab_username = GTK_ENTRY (gtk_entry_new());
 	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (uidata->kolab_username), TRUE, TRUE, 0);
 
 	/* Existing Kolab PIM type folders for selected account */
@@ -440,16 +434,14 @@ e_kolab_account_setup_backend_create (EPlugin *epl,
 	gtk_box_pack_start (GTK_BOX (kolab_vbox), GTK_WIDGET (hbox), TRUE, TRUE, 0);
 	spacer = gtk_label_new("   ");
 	gtk_box_pack_start (GTK_BOX (hbox), spacer, FALSE, FALSE, 0);
-	tmp_str = g_strconcat (_("Server PIM-Folders"), ":", NULL);
-	label = gtk_label_new_with_mnemonic (tmp_str);
-	g_free (tmp_str);
+	label = gtk_label_new (C_("Account Setup", "Server PIM-Folders:"));
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	uidata->kolab_folders_avail = GTK_COMBO_BOX_TEXT (gtk_combo_box_text_new ());
 	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (uidata->kolab_folders_avail), TRUE, TRUE, 0);
 	/* FIXME add Kolab PIM folders to GTK box */
 	g_warning ("%s: FIXME add Kolab PIM folders to GTK box", __func__);
 	gtk_combo_box_set_active (GTK_COMBO_BOX (uidata->kolab_folders_avail), 0);
-	uidata->retrieve_folder_list = GTK_BUTTON (gtk_button_new_with_label (_("Retrieve")));
+	uidata->retrieve_folder_list = GTK_BUTTON (gtk_button_new_with_label (C_("Account Setup", "Retrieve")));
 	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (uidata->retrieve_folder_list), FALSE, FALSE, 0);
 
 	/* Kolab folder name option */
@@ -458,13 +450,13 @@ e_kolab_account_setup_backend_create (EPlugin *epl,
 	spacer = gtk_label_new("   ");
 	gtk_box_pack_start (GTK_BOX (hbox), spacer, FALSE, FALSE, 0);
 	if (widget_type == KOLAB_WIDGET_TYPE_CONTACT)
-		tmp_str = g_strconcat (_("Selected Contact Folder"), ":", NULL);
+		tmp_str = g_strdup (C_("Account Setup", "Selected Contact Folder:"));
 	else
-		tmp_str = g_strconcat (_("Selected Calendar Folder"), ":", NULL);
-	label = gtk_label_new_with_mnemonic (tmp_str);
+		tmp_str = g_strdup (C_("Account Setup", "Selected Calendar Folder:"));
+	label = gtk_label_new (tmp_str);
 	g_free (tmp_str);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-	uidata->kolab_foldername = GTK_ENTRY(gtk_entry_new());
+	uidata->kolab_foldername = GTK_ENTRY (gtk_entry_new());
 	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (uidata->kolab_foldername), TRUE, TRUE, 0);
 
 	/* Encryption setting */
@@ -472,9 +464,7 @@ e_kolab_account_setup_backend_create (EPlugin *epl,
 	gtk_box_pack_start (GTK_BOX (kolab_vbox), GTK_WIDGET (hbox), TRUE, TRUE, 0);
 	spacer = gtk_label_new("   ");
 	gtk_box_pack_start (GTK_BOX (hbox), spacer, FALSE, FALSE, 0);
-	tmp_str = g_strconcat (_("Encryption Method"), ":", NULL);
-	label = gtk_label_new_with_mnemonic(tmp_str);
-	g_free (tmp_str);
+	label = gtk_label_new(C_("Security", "Encryption Method:"));
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	uidata->encryption_method = GTK_COMBO_BOX_TEXT (gtk_combo_box_text_new ());
 	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (uidata->encryption_method), TRUE, TRUE, 0);
@@ -488,31 +478,28 @@ e_kolab_account_setup_backend_create (EPlugin *epl,
 	gtk_box_pack_start (GTK_BOX (kolab_vbox), GTK_WIDGET (hbox), TRUE, TRUE, 0);
 	spacer = gtk_label_new("   ");
 	gtk_box_pack_start (GTK_BOX (hbox), spacer, FALSE, FALSE, 0);
-	tmp_str = g_strconcat (_("PKCS #11 Infrastructure"), ":", NULL);
-	label = gtk_label_new_with_mnemonic(tmp_str);
-	g_free (tmp_str);
+	label = gtk_label_new (C_("Security", "PKCS #11 Infrastructure:"));
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	uidata->require_pkcs11_infrastructure = GTK_CHECK_BUTTON (gtk_check_button_new_with_label ("PIN:"));
-	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (uidata->require_pkcs11_infrastructure), TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (uidata->require_pkcs11_infrastructure), FALSE, FALSE, 0);
 	uidata->pkcs11_pin = GTK_ENTRY (gtk_entry_new ());
 	gtk_entry_set_visibility (uidata->pkcs11_pin, FALSE);
 	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (uidata->pkcs11_pin), TRUE, TRUE, 0);
 
 	/* Options section */
 	section = gtk_label_new (NULL);
-	tmp_str = g_strconcat ("<b>", _("Kolab Folder Options"), "</b>", NULL);
+	tmp_str = g_strconcat ("<b>", C_("Account Setup", "Kolab Folder Options"), "</b>", NULL);
 	gtk_label_set_markup (GTK_LABEL (section), tmp_str);
 	g_free (tmp_str);
-	gtk_misc_set_alignment (GTK_MISC (section), 0.0, 0.0);
+	gtk_misc_set_alignment (GTK_MISC (section), 0.0, 0.5);
+	gtk_widget_set_margin_top (GTK_WIDGET (section), 6);
 	gtk_box_pack_start (GTK_BOX (kolab_vbox), section, FALSE, FALSE, 0);
 
 	hbox = gtk_hbox_new (FALSE, 10);
 	gtk_box_pack_start (GTK_BOX (kolab_vbox), GTK_WIDGET (hbox), TRUE, TRUE, 0);
 	spacer = gtk_label_new ("   ");
 	gtk_box_pack_start (GTK_BOX (hbox), spacer, FALSE, FALSE, 0);
-	tmp_str = g_strconcat (_("Conflict Solving Strategy"), ":", NULL);
-	label = gtk_label_new_with_mnemonic (tmp_str);
-	g_free (tmp_str);
+	label = gtk_label_new (C_("Account Setup", "Conflict Solving Strategy:"));
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	uidata->kolab_conflict_strategy = GTK_COMBO_BOX_TEXT (gtk_combo_box_text_new ());
 	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (uidata->kolab_conflict_strategy), TRUE, TRUE, 0);
