@@ -54,7 +54,8 @@ e_kolab_folder_metadata_ui_new (void)
 	GtkWidget *grid = NULL;
 
 	uidata->widgets = g_new0 (KolabFolderMetaUIWidgets, 1);
-	uidata->widgets->container = gtk_frame_new (_("Folder Type (Annotation)"));
+	uidata->widgets->container = gtk_frame_new (C_("Kolab Folder Metadata",
+	                                               "Folder Type (Annotation)"));
 	gtk_container_set_border_width (GTK_CONTAINER (uidata->widgets->container), 6);
 
 	grid = gtk_grid_new ();
@@ -63,24 +64,33 @@ e_kolab_folder_metadata_ui_new (void)
 	gtk_container_set_border_width (GTK_CONTAINER (grid), 16);
 	gtk_container_add (GTK_CONTAINER (uidata->widgets->container), grid);
 
-	widget = gtk_radio_button_new_with_label (NULL, C_("Folder Type", "Mail"));
+	widget = gtk_radio_button_new_with_label (NULL, C_("Kolab Folder Type",
+	                                                   "Mail"));
 	uidata->widgets->radio_btn_type_mail = widget;
 	uidata->widgets->radio_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget));
 	gtk_container_add (GTK_CONTAINER (grid), widget);
 
-	widget = gtk_radio_button_new_with_label (uidata->widgets->radio_group, C_("Folder Type", "Calendar"));
+	widget = gtk_radio_button_new_with_label (uidata->widgets->radio_group,
+	                                          C_("Kolab Folder Type",
+	                                             "Calendar"));
 	uidata->widgets->radio_btn_type_calendar = widget;
 	gtk_container_add (GTK_CONTAINER (grid), widget);
 
-	widget = gtk_radio_button_new_with_label (uidata->widgets->radio_group, C_("Folder Type", "Memos"));
+	widget = gtk_radio_button_new_with_label (uidata->widgets->radio_group,
+	                                          C_("Kolab Folder Type",
+	                                             "Memos"));
 	uidata->widgets->radio_btn_type_memos = widget;
 	gtk_container_add (GTK_CONTAINER (grid), widget);
 
-	widget = gtk_radio_button_new_with_label (uidata->widgets->radio_group, C_("Folder Type", "Tasks"));
+	widget = gtk_radio_button_new_with_label (uidata->widgets->radio_group,
+	                                          C_("Kolab Folder Type",
+	                                             "Tasks"));
 	uidata->widgets->radio_btn_type_tasks = widget;
 	gtk_container_add (GTK_CONTAINER (grid), widget);
 
-	widget = gtk_radio_button_new_with_label (uidata->widgets->radio_group, C_("Folder Type", "Contacts"));
+	widget = gtk_radio_button_new_with_label (uidata->widgets->radio_group,
+	                                          C_("Kolab Folder Type",
+	                                             "Contacts"));
 	uidata->widgets->radio_btn_type_contacts = widget;
 	gtk_container_add (GTK_CONTAINER (grid), widget);
 
@@ -103,6 +113,8 @@ e_kolab_folder_metadata_ui_free (KolabFolderMetaUIData *uidata)
 		g_free (uidata->widgets);
 
 	kolab_data_folder_metadata_free (uidata->metadata);
+	if (uidata->selected_folder != NULL)
+		g_free (uidata->selected_folder);
 
 	g_free (uidata);
 }
