@@ -55,7 +55,6 @@ struct _KolabFolderPermUIWidgets {
 	GtkWidget *edit_entry_box;
 	GtkWidget *edit_btn_retrieve;
 	GSList *radio_group;
-	GtkWidget *radio_btn_perm_none;
 	GtkWidget *radio_btn_perm_read;
 	GtkWidget *radio_btn_perm_append;
 	GtkWidget *radio_btn_perm_write;
@@ -66,6 +65,7 @@ typedef struct _KolabFolderPermUIData KolabFolderPermUIData;
 struct _KolabFolderPermUIData {
 	KolabFolderPermUIWidgets *widgets;
 	KolabDataFolderPermissions *permissions;
+	gchar *selected_folder;
 };
 
 /*----------------------------------------------------------------------------*/
