@@ -31,7 +31,6 @@
 
 #include <camel/camel-kolab-imapx-provider.h>
 #include <camel/camel-kolab-imapx-store.h>
-#include <camel/camel-kolab-imapx-folder.h>
 #include <camel/camel-kolab-session.h>
 
 #include <libekolabutil/camel-system-headers.h>
@@ -1017,7 +1016,9 @@ kolab_mail_imap_client_go_online (KolabMailImapClient *self,
 	priv->foldername = NULL;
 
 	/* connect the camel service */
-	ok = camel_service_connect_sync (CAMEL_SERVICE (priv->store), &tmp_err);
+	ok = camel_service_connect_sync (CAMEL_SERVICE (priv->store),
+	                                 cancellable,
+	                                 &tmp_err);
 	camel_kolab_session_set_token_pin (priv->session, NULL); /* forget pin */
 	if (! ok) {
 		g_propagate_error (err, tmp_err);
@@ -1077,6 +1078,7 @@ kolab_mail_imap_client_go_offline (KolabMailImapClient *self,
 
 	ok = camel_service_disconnect_sync (CAMEL_SERVICE (priv->store),
 	                                    TRUE, /* try to disconnect cleanly */
+	                                    cancellable,
 	                                    &tmp_err);
 	if (! ok) {
 		g_propagate_error (err, tmp_err);
@@ -1211,8 +1213,7 @@ kolab_mail_imap_client_get_folder_uidvalidity (KolabMailImapClient *self,
 	 *      read 0 (zero), so we cannot detect a change
 	 *      there presently
 	 */
-	uidvalidity = camel_kolab_imapx_folder_get_uidvalidity (CAMEL_KOLAB_IMAPX_FOLDER (folder),
-	                                                        &tmp_err);
+	uidvalidity = kolab_util_camel_imapx_folder_get_uidvalidity (CAMEL_IMAPX_FOLDER (folder));
 	g_object_unref (folder);
 	if (tmp_err != NULL) {
 		g_propagate_error (err, tmp_err);
