@@ -45,16 +45,16 @@
 /*----------------------------------------------------------------------------*/
 
 static const gchar *kolab_sync_strategy_desc[KOLAB_SYNC_LAST_STRATEGY] = {
-	N_(KOLAB_STRATEGY_DESC_NEWEST),
-	N_(KOLAB_STRATEGY_DESC_SERVER),
-	N_(KOLAB_STRATEGY_DESC_CLIENT),
-	N_(KOLAB_STRATEGY_DESC_DUPE)
+	NC_("Sync Conflict Resolution", KOLAB_STRATEGY_DESC_NEWEST),
+	NC_("Sync Conflict Resolution", KOLAB_STRATEGY_DESC_SERVER),
+	NC_("Sync Conflict Resolution", KOLAB_STRATEGY_DESC_CLIENT),
+	NC_("Sync Conflict Resolution", KOLAB_STRATEGY_DESC_DUPE)
 };
 
 static const gchar *kolab_tls_variant_desc[KOLAB_TLS_LAST_VARIANT] = {
-	N_(KOLAB_TLS_DESC_VARIANT_NONE),
-	N_(KOLAB_TLS_DESC_VARIANT_SSL),
-	N_(KOLAB_TLS_DESC_VARIANT_TLS)
+	NC_("Security", KOLAB_TLS_DESC_VARIANT_NONE),
+	NC_("Security", KOLAB_TLS_DESC_VARIANT_SSL),
+	NC_("Security", KOLAB_TLS_DESC_VARIANT_TLS)
 };
 
 /*----------------------------------------------------------------------------*/
