@@ -58,7 +58,13 @@ gboolean kolab_util_camel_shutdown (GError **err);
 /*----------------------------------------------------------------------------*/
 /* Camel helper functions */
 
-gchar* kolab_util_camel_get_storage_path (CamelService *service, CamelSession *session, GError **err);
+gchar*
+kolab_util_camel_get_storage_path (CamelService *service,
+                                   CamelSession *session,
+                                   GError **err);
+
+guint64
+kolab_util_camel_imapx_folder_get_uidvalidity (CamelIMAPXFolder *folder);
 
 /*----------------------------------------------------------------------------*/
 
